@@ -7,10 +7,14 @@ from cloudshell.helpers.app_import.upload_app_xml import upload_app_to_cloudshel
 
 
 class SaveAppUtility:
-    def __init__(self, sandbox, resource_name, app_name, server_address, admin_user, admin_password, display_image_url='', new_app_name=''):
+    def __init__(self, sandbox, resource_name, server_address, admin_user, admin_password, display_image_url='', new_app_name=''):
         self.sandbox = sandbox
         self.resource_name = resource_name
-        self.app_name = app_name
+
+        for vm in self.sandbox.automation_api.GetReservationDetails(self.sandbox.id).ReservationDescription.Resources:
+            if vm.Name == self.resource_name:
+                self.app_name = vm.AppDetails.AppName
+
         self.server_address = server_address
         self.admin_user = admin_user
         self.admin_password = admin_password
@@ -18,7 +22,7 @@ class SaveAppUtility:
         self.display_image_url = display_image_url
 
         if new_app_name == '':
-            self.new_app_name = app_name
+            self.new_app_name = self.app_name
         else:
             self.new_app_name = new_app_name
 
